@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai
-version: 3.2.0
-id: wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-key: wai_Jv99SxPGQFiAK3okD1Hbf4
+version: 3.2.1
+id: wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
+key: wai_6jy2slE0WAv9HznU5yT87k
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -17,15 +17,15 @@ exposed: True
 exposed-modules:
     Network.Wai Network.Wai.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-3.2.0
-hs-libraries: HSwai-3.2.0-Jv99SxPGQFiAK3okD1Hbf4
+import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-3.2.1
+hs-libraries: HSwai-3.2.1-6jy2slE0WAv9HznU5yT87k
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
